@@ -52,7 +52,7 @@
 #define GCC_INSTALL_PREFIX ""
 
 /* Define if we have libxml2 */
-#define CLANG_HAVE_LIBXML 1
+/* #undef CLANG_HAVE_LIBXML */
 
 /* Define if we have z3 and want to build it */
 /* #undef CLANG_ANALYZER_WITH_Z3 */
@@ -61,7 +61,7 @@
 /* #undef CLANG_HAVE_RLIMITS */
 
 /* The LLVM product name and version */
-#define BACKEND_PACKAGE_STRING "LLVM 7.0.1"
+#define BACKEND_PACKAGE_STRING "LLVM 8.0.0"
 
 /* Linker version detected at compile time. */
 /* #undef HOST_LINK_VERSION */
