@@ -10,6 +10,8 @@ cmake \
   -DCLANG_INCLUDE_DOCS=OFF \
   -DLLVM_INCLUDE_TESTS=OFF \
   -DLLVM_INCLUDE_DOCS=OFF \
+  -DLLVM_ENABLE_LIBXML2=OFF \
+  -DCMAKE_AR=$AR \
   ..
 
 make -j${CPU_COUNT}
